summaryrefslogtreecommitdiff
path: root/gnuradio-runtime/lib/flat_flowgraph.cc
diff options
context:
space:
mode:
authorDavid Sorber <david.sorber@blacklynx.tech>2021-10-13 10:15:55 -0400
committermormj <34754695+mormj@users.noreply.github.com>2021-10-25 11:27:01 -0400
commit47c374211221f3c636e0be2238ef233dd353697d (patch)
tree7988a999efa96797e4011122f104ee2988c7ef4e /gnuradio-runtime/lib/flat_flowgraph.cc
parent0c08ee00da21f48d30273338b2c62aacbc912eff (diff)
runtime: rename buffer_context to transfer type; also rename the
MAKE_CUSTOM_BUFFER_TYPE macro function to DEFINE_CUSTOM_BUFFER_TYPE; mark unused parameters from virtual functions with the [[maybe_unused]] C++ attribute Signed-off-by: David Sorber <david.sorber@blacklynx.tech>
Diffstat (limited to 'gnuradio-runtime/lib/flat_flowgraph.cc')
-rw-r--r--gnuradio-runtime/lib/flat_flowgraph.cc18
1 files changed, 9 insertions, 9 deletions
diff --git a/gnuradio-runtime/lib/flat_flowgraph.cc b/gnuradio-runtime/lib/flat_flowgraph.cc
index ef96ef21ac..3856b170d9 100644
--- a/gnuradio-runtime/lib/flat_flowgraph.cc
+++ b/gnuradio-runtime/lib/flat_flowgraph.cc
@@ -201,26 +201,26 @@ void flat_flowgraph::connect_block_inputs(basic_block_sptr block)
if (!src_grblock)
throw std::runtime_error("connect_block_inputs found non-gr::block");
// In order to determine the buffer context, we need to examine both
// the upstream and the downstream buffer_types
buffer_type src_buf_type =
src_grblock->output_signature()->stream_buffer_type(src_port);
buffer_type dest_buf_type =
grblock->input_signature()->stream_buffer_type(dst_port);
- buffer_context context;
+ transfer_type buf_xfer_type;
if (src_buf_type == buffer_double_mapped::type &&
dest_buf_type == buffer_double_mapped::type) {
- context = buffer_context::HOST_TO_HOST;
+ buf_xfer_type = transfer_type::HOST_TO_HOST;
} else if (src_buf_type != buffer_double_mapped::type &&
dest_buf_type == buffer_double_mapped::type) {
- context = buffer_context::DEVICE_TO_HOST;
+ buf_xfer_type = transfer_type::DEVICE_TO_HOST;
} else if (src_buf_type == buffer_double_mapped::type &&
dest_buf_type != buffer_double_mapped::type) {
- context = buffer_context::HOST_TO_DEVICE;
+ buf_xfer_type = transfer_type::HOST_TO_DEVICE;
} else if (src_buf_type != buffer_double_mapped::type &&
dest_buf_type != buffer_double_mapped::type) {
- context = buffer_context::DEVICE_TO_DEVICE;
+ buf_xfer_type = transfer_type::DEVICE_TO_DEVICE;
}
buffer_sptr src_buffer;
@@ -255,12 +255,12 @@ void flat_flowgraph::connect_block_inputs(basic_block_sptr block)
}
}
- // Set buffer's context
- src_buffer->set_context(context);
+ // Set buffer's transfer type
+ src_buffer->set_transfer_type(buf_xfer_type);
std::ostringstream msg;
msg << "Setting input " << dst_port << " from edge " << (*e).identifier()
- << " context: " << context;
+ << " transfer type: " << buf_xfer_type;
GR_LOG_DEBUG(d_debug_logger, msg.str());
detail->set_input(dst_port,
@@ -201,26 +201,26 @@ void flat_flowgraph::connect_block_inputs(basic_block_sptr block)
if (!src_grblock)
throw std::runtime_error("connect_block_inputs found non-gr::block");
- // In order to determine the buffer context, we need to examine both
+ // In order to determine the buffer's transfer type, we need to examine both
// the upstream and the downstream buffer_types
buffer_type src_buf_type =